summaryrefslogtreecommitdiff
path: root/core/arch/arm/tee/arch_svc.c
diff options
context:
space:
mode:
Diffstat (limited to 'core/arch/arm/tee/arch_svc.c')
-rw-r--r--core/arch/arm/tee/arch_svc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/arch/arm/tee/arch_svc.c b/core/arch/arm/tee/arch_svc.c
index 8a89ce9..f6767d7 100644
--- a/core/arch/arm/tee/arch_svc.c
+++ b/core/arch/arm/tee/arch_svc.c
@@ -35,12 +35,12 @@
#include <tee/tee_svc_cryp.h>
#include <tee/tee_svc_storage.h>
#include <tee/se/svc.h>
+#include <tee/svc_cache.h>
#include <tee_syscall_numbers.h>
#include <trace.h>
#include <util.h>
#include "arch_svc_private.h"
-#include "svc_cache.h"
#if (TRACE_LEVEL == TRACE_FLOW) && defined(CFG_TEE_CORE_TA_TRACE)
#define TRACE_SYSCALLS
@@ -201,8 +201,8 @@ void tee_svc_handler(struct thread_svc_regs *regs)
/* TA has just entered kernel mode */
tee_ta_update_session_utime_suspend();
- /* Restore IRQ which are disabled on exception entry */
- thread_restore_irq();
+ /* Restore foreign interrupts which are disabled on exception entry */
+ thread_restore_foreign_intr();
get_scn_max_args(regs, &scn, &max_args);